pub struct ExDefaultHasher(/* private fields */);Expand description
Specifications for the behavior of
std::collections::hash_map::DefaultHasher.
We model a DefaultHasher as having a view (i.e., an abstract
state) of type Seq<Seq<u8>>. This reflects the sequence of write
operations performed so far, where each write is modeled as having
written a sequence of bytes. There’s also a specification for
how a view will be transformed by finish into a u64.